import QtQuick 2.4
import Ubuntu.Components 1.3
import Ubuntu.Components.ListItems 1.3 as ListItem



Page {
	id: aboutPage
	title: i18n.tr("About")
	
	header: PageHeader {
		id: pageHeader
		title: i18n.tr("About")
		StyleHints {
			foregroundColor: '#ffffff'
			backgroundColor: '#ffb84f'
			dividerColor: UbuntuColors.slate
		}

		leadingActionBar {
			numberOfSlots: 1
			actions: [
				Action {
					id: actionSettings
					iconName: "back"
					text: i18n.tr("Back")
					onTriggered: {
						onClicked: mainPageStack.pop(aboutPage)
					}
				}
			]
		}
	}

	Flickable {
		id: flickable
		anchors.fill: parent
		anchors.topMargin: units.gu(5)
		contentHeight: appColumn.height + launchpadColumn.height + devColumn.height +  poweredByColumn.height + units.gu(14)

		Column {
			id: appColumn
			spacing: units.gu(1)
			anchors {
				top: parent.top; left: parent.left; right: parent.right; topMargin: units.gu(5)
			}
			Image {
				id: appImage
				source: "../uwp.png"
				anchors.horizontalCenter: parent.horizontalCenter
			}
			Label {
				width: parent.width
				wrapMode: Text.WordWrap
				horizontalAlignment: Text.AlignHCenter
				text: "© uWriter 2015-" + new Date().getFullYear()
			}
			Label {
				width: parent.width
				wrapMode: Text.WordWrap
				horizontalAlignment: Text.AlignHCenter
				text: i18n.tr("Version %1. Under License %2").arg("0.17").arg("<a href=\"http://www.gnu.org/licenses/gpl-3.0.en.html\">GPL3</a>")
				onLinkActivated: Qt.openUrlExternally(link)
			}
		}

		Column {
			id: launchpadColumn
			anchors.top: appColumn.bottom
			anchors.topMargin: units.gu(4)
			width: parent.width
			ListItem.Header {
				id: lpHeader
				text: i18n.tr("Resources")
			}

			Repeater {
				id: lpListView

				model: lpModel
				delegate: ListItem.Standard {
					progression: true
					showDivider: false
					text: model.name
					onClicked: Qt.openUrlExternally(model.link)
				}
			}

			ListModel {
				id: lpModel
				Component.onCompleted: initialize()
				function initialize() {
					lpModel.append({ name: i18n.tr("Rate on Store"), link: "scope://com.canonical.scopes.clickstore?q=uwriter" })
					lpModel.append({ name: i18n.tr("Bugs"), link: "https://bugs.launchpad.net/uwriter" })
					lpModel.append({ name: i18n.tr("Answers"), link: "https://answers.launchpad.net/uwriter" })
					lpModel.append({ name: i18n.tr("Contact"), link: "mailto:costales.marcos@gmail.com" })
				}
			}
		}

		Column {
			id: devColumn
			anchors.top: launchpadColumn.bottom
			anchors.topMargin: units.gu(2)
			width: parent.width
			ListItem.Header {
				id: devHeader
				text: i18n.tr("Developer")
			}

			Repeater {
				id: devListView

				model: devModel
				delegate: ListItem.Standard {
					progression: true
					showDivider: false
					text: model.name
					onClicked: Qt.openUrlExternally(model.link)
				}
			}

			ListModel {
				id: devModel
				Component.onCompleted: initialize()
				function initialize() {
					devModel.append({ name: "Marcos Costales", link: "https://wiki.ubuntu.com/costales" })
				}
			}
		}

		
		Column {
			id: poweredByColumn
			anchors.top: devColumn.bottom
			anchors.topMargin: units.gu(2)
			width: parent.width

			ListItem.Header {
				id: poweredbyHeader
				text: i18n.tr("Powered by")
			}

			Repeater {
				id: poweredbyListView

				model: poweredbyModel
				delegate: ListItem.Standard {
					progression: true
					showDivider: false
					text: model.name
					onClicked: Qt.openUrlExternally(model.link)
				}
			}

			ListModel {
				id: poweredbyModel
				Component.onCompleted: initialize()
				function initialize() {
					poweredbyModel.append({ name: "tinyMCE", link: "https://www.tinymce.com" })
				}
			}
		}
	}
}
