/*
 * uWriter http://launchpad.net/uwriter
 * Copyright (C) 2015 Marcos Alvarez Costales https://launchpad.net/~costales
 *
 * uWriter is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * uWriter is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

import QtQuick 2.4
import Ubuntu.Components 1.3
import Ubuntu.Components.Popups 1.3
import Ubuntu.Web 0.2
import com.canonical.Oxide 1.0 as Oxide
import Qt.labs.settings 1.0
import "js/utils.js" as QmlJs


MainView {
    objectName: "mainView"

    applicationName: "uwp.costales"

    width: units.gu(100)
    height: units.gu(70)
    anchorToKeyboard: true

    PageStack {
        id: mainPageStack
        anchors.fill: parent
        width: parent.width

        property var settings: Settings {
            property bool deprecatedShowed: false
        }

        property string filename: ''
        property string saveAsOperation: ''
        property bool   deprecatedShowed2: false
        
        Component.onCompleted: {
            mainPageStack.push(pageMain);
            if (!mainPageStack.settings.deprecatedShowed) {
                PopupUtils.open(deprecated);
            }
            i18n.domain = "uwriter";
            i18n.bindtextdomain("uwriter", "i18n/mo");
        }
        
        function executeJavaScript(code) {
            var req = webview.rootFrame.sendMessage("messaging://", "EXECUTE", {code: code});
            req.onerror = function (code, explanation) {
                console.log("Error " + code + ": " + explanation)
            }
        }



        Page {
            id: pageMain
            
            onVisibleChanged: {
                if (visible)
                    webview.forceActiveFocus();
            }
            
            property bool btnsEnabled: false
            
            header: PageHeader {
                id: pageHeader
                title: i18n.tr("uWriter")
                StyleHints {
                    foregroundColor: '#ffffff'
                    backgroundColor: '#ffb84f'
                    dividerColor: UbuntuColors.slate
                }
                leadingActionBar {
                    numberOfSlots: 1
                    actions: [
                        Action {
                            id: actionSettings
                            iconName: "navigation-menu"
                            shortcut: "Ctrl+M"
                            enabled: pageMain.btnsEnabled
                            text: i18n.tr("Menu")
                            onTriggered: {
                                Qt.inputMethod.hide();
                                mainPageStack.push(Qt.resolvedUrl("Menu.qml"))
                            }
                        }
                    ]
                }
                trailingActionBar {
                    numberOfSlots: 5
                    actions: [
                        Action {
                            id: actionSaveAs
                            iconName: "save-as"
                            enabled: pageMain.btnsEnabled
                            text: i18n.tr("Save as")
                            onTriggered: {
                                mainPageStack.push(Qt.resolvedUrl("SaveAs.qml"), {"setNewDoc": false, "callLoadDoc": false, "mainFilename": mainPageStack.filename})
                            }
                        },
                        Action {
                            id: actionSave
                            iconName: "save"
                            shortcut: "Ctrl+S"
                            enabled: pageMain.btnsEnabled
                            text: i18n.tr("Save")
                            onTriggered: {
                                if (!mainPageStack.filename) {
                                    mainPageStack.push(Qt.resolvedUrl("SaveAs.qml"), {"setNewDoc": false, "callLoadDoc": false, "mainFilename": mainPageStack.filename})
                                }
                                else {
                                    mainPageStack.executeJavaScript("qml_save_content(false)");
                                }
                            }
                        },
                        Action {
                            id: actionLoad
                            iconName: "document-open"
                            shortcut: "Ctrl+O"
                            enabled: pageMain.btnsEnabled
                            text: i18n.tr("Load")
                            onTriggered: {
                                mainPageStack.executeJavaScript("qml_query_modified('load')");
                            }
                        },
                        Action {
                            id: actionNew
                            iconName: "note"
                            shortcut: "Ctrl+N"
                            enabled: pageMain.btnsEnabled
                            text: i18n.tr("New")
                            onTriggered: {
                                mainPageStack.executeJavaScript("qml_query_modified('new')");
                            }
                        },
                        Action {
                            id: actionDeprecated
                            iconName: "security-alert"
                            enabled: pageMain.btnsEnabled
                            text: i18n.tr("Deprecated")
                            onTriggered: {
                                if (!mainPageStack.deprecatedShowed2) {
                                    mainPageStack.deprecatedShowed2 = true;
                                    PopupUtils.open(deprecated);
                                }
                                else {
                                    mainPageStack.executeJavaScript("browse_files()");
                                }
                                
                            }
                        }
                    ]
                }
            }

            WebContext {
                id: webcontext
                userAgent: "Mozilla/5.0 (Linux; Android 5.0; Nexus 5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.102 Mobile Safari/537.36"
                userScripts: [
                    Oxide.UserScript {
                        context: "messaging://"
                        url: Qt.resolvedUrl("js/oxide.js")
                    }
                ]
            }

            WebView {
                id: webview
                anchors.top: pageHeader.bottom
                anchors.bottom: parent.bottom
                anchors.left: parent.left
                anchors.right: parent.right
                //anchors.fill: parent
                z: -6
                context: webcontext
                url: "../uwp/index.html"
                preferences.allowFileAccessFromFileUrls: true
                preferences.allowUniversalAccessFromFileUrls: true
                preferences.appCacheEnabled: true
                preferences.javascriptCanAccessClipboard: true
                preferences.javascriptEnabled: true

                onLoadingStateChanged: {
                    if (!loading && !mainPageStack.onLoadingExecuted)
                        pageMain.btnsEnabled = true;
                }
                
                onNavigationRequested:{
                    var url = request.url.toString();
                    
                    // Save
                    if (QmlJs.url_starts_with(url, 'http://save/')) {
                        var contentHTML = request.url.toString().replace(/^http:\/\/save\//,'');
                        QmlJs.saveFile(mainPageStack.filename, contentHTML);
                    }
                    
                    // Save & New
                    if (QmlJs.url_starts_with(url, 'http://save_and_new/')) {
                        var contentHTML = request.url.toString().replace(/^http:\/\/save_and_new\//,'');
                        QmlJs.saveFile(mainPageStack.filename, contentHTML);
                        mainPageStack.filename = '';
                    }
                    
                    // New
                    if (QmlJs.url_starts_with(url, 'http://modified_new/')) {
                        if (url == 'http://modified_new/false') {
                            mainPageStack.filename = '';
                            mainPageStack.executeJavaScript("qml_file_new()");
                        }
                        else {
                            mainPageStack.saveAsOperation = 'new';
                            PopupUtils.open(ask4save);
                        }
                    }
                    
                    // Load
                    if (QmlJs.url_starts_with(url, 'http://modified_load/')) {
                        if (url == 'http://modified_load/false') {
                            mainPageStack.push(Qt.resolvedUrl("LoadFile.qml"))
                        }
                        else {
                            mainPageStack.saveAsOperation = 'load';
                            PopupUtils.open(ask4save);
                        }
                    }
                    
                    // New
                    if (QmlJs.url_starts_with(url, 'http://new/')) {
                        mainPageStack.filename = '';
                    }
                    
                    request.action = Oxide.NavigationRequest.ActionReject;
                }
            }
        }
        
    }
    
    Component {
         id: ask4save
         Dialog {
            id: dialogueAsk4Save
            title: i18n.tr("Save file")
            text: i18n.tr("Do you want to save the text?")
            Button {
                text: i18n.tr("Yes")
                color: UbuntuColors.green
                onClicked: {
                    PopupUtils.close(dialogueAsk4Save)
                    if (mainPageStack.filename) {
                        mainPageStack.executeJavaScript("qml_save_content(true)");
                        if (mainPageStack.saveAsOperation != 'new')
                            mainPageStack.push(Qt.resolvedUrl("LoadFile.qml"));
                    }
                    else {
                        if (mainPageStack.saveAsOperation == 'new')
                            mainPageStack.push(Qt.resolvedUrl("SaveAs.qml"), {"setNewDoc": true, "callLoadDoc": false, "mainFilename": mainPageStack.filename});
                        if (mainPageStack.saveAsOperation == 'load')
                            mainPageStack.push(Qt.resolvedUrl("SaveAs.qml"), {"setNewDoc": false, "callLoadDoc": true, "mainFilename": mainPageStack.filename});
                    }
                }
            }
            Button {
                text: i18n.tr("No")
                color: UbuntuColors.red
                onClicked: {
                    PopupUtils.close(dialogueAsk4Save);
                    mainPageStack.filename = '';
                    mainPageStack.executeJavaScript("qml_file_new()");
                    if (mainPageStack.saveAsOperation == 'load')
                        mainPageStack.push(Qt.resolvedUrl("LoadFile.qml"));
                }
            }
            Button {
                text: i18n.tr("Cancel")
                onClicked: {
                    PopupUtils.close(dialogueAsk4Save);
                }
            }
        }
    }
    
    
    
    
    
    
    
        Component {
         id: deprecated
         Dialog {
            id: dialogueDeprecated
            title: "Access to deprecated files"
            text: "Previous versions of uWriter stored the files inside an internal database.\n\nNow uWriter is storing them in a local directory:\n~/.local/share/uwp.costales/*.html\n\nI could automatize this task, but your documents are so sensible to me, then, please, open each older document clicking on the red shield in header and save it as usual with the 2º button (save-as) in the header.\n\nIn next version, this option will be removed, then save them now!"
            Button {
                text: i18n.tr("OK")
                color: UbuntuColors.red
                onClicked: {
                    PopupUtils.close(dialogueDeprecated);
                    if (mainPageStack.settings.deprecatedShowed)
                        mainPageStack.executeJavaScript("browse_files()");
                    else 
                        mainPageStack.settings.deprecatedShowed = true;
                }
            }
        }
    }

    
    
    
    
}
